@@ -1,13 +1,8 @@
 # coding: utf8
 from __future__ import unicode_literals
 
-import os
-from pathlib import Path
-import spacy
-from spacy.util import load_model_from_init_py, get_model_meta
-from spacy.language import Language
-from spacy.tokens import Span, Doc
-from spacy.matcher import Matcher
+from spacy.util import load_model_from_init_py
+from spacy.tokens import Doc
 import warnings
 from . import util
 
